@@ -42,7 +42,8 @@ class NumpySerializer(json.JSONEncoder):
 
 def sgd_classifier_to_json(classifier):
   args_dict = {}
-  for key in inspect.getargspec(type(classifier).__init__).args:
+  needed_args = inspect.signature(type(classifier).__init__).parameters.keys()
+  for key in needed_args:
     if hasattr(classifier, key):
       args_dict[key] = getattr(classifier, key)
   params_dict = {}
@@ -56,7 +57,7 @@ def sgd_classifier_to_json(classifier):
 
 def sgd_classifier_from_json(cls, full_json):
   full_dict = json.loads(full_json)
-  needed_args = inspect.getargspec(cls.__init__).args
+  needed_args = inspect.signature(cls.__init__).parameters.keys()
   args = {key: val for key, val in full_dict['args'].items()
           if key in needed_args}
   new_classifier = cls(**args)
@@ -68,7 +69,7 @@ def sgd_classifier_from_json(cls, full_json):
 
 def hasher_from_json(cls, full_json):
   full_dict = json.loads(full_json)
-  needed_args = inspect.getargspec(cls.__init__).args
+  needed_args = inspect.signature(cls.__init__).parameters.keys()
   args = {key: val for key, val in full_dict.items()
           if key in needed_args}
   return cls(**args)
